@@ -2,6 +2,7 @@
  * File: downloads.cc
  *
  * Copyright (C) 2005-2007 Jorge Arellano Cid <jcid@dillo.org>
+ * Copyright (C) 2024 Rodrigo Arias Mallo <rodarima@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +42,7 @@
 #include <FL/Fl_Box.H>
 #include <FL/Fl_Button.H>
 
+#include "config.h"
 #include "dpiutil.h"
 #include "../dpip/dpip.h"
 
@@ -68,7 +70,7 @@ protected:
    void draw();
 public:
    ProgressBar(int x, int y, int w, int h, const char *lbl = 0);
-   void range(double min, double max, double step = 1)  {
+   void range(double min, double max, double step = 1) {
       mMin = min; mMax = max; mStep = step;
    };
    void step(double step)        { mPresent += step; redraw(); };
@@ -318,11 +320,14 @@ DLItem::DLItem(const char *full_filename, const char *url)
    /* avoid malicious SMTP relaying with FTP urls */
    if (dStrnAsciiCasecmp(esc_url, "ftp:/", 5) == 0)
       Filter_smtp_hack(esc_url);
-   dl_argv = new char*[8];
+   dl_argv = new char*[10];
    int i = 0;
+   const char *user_agent = "Dillo/" VERSION;
    dl_argv[i++] = (char*)"wget";
    if (stat(fullname, &ss) == 0)
       init_bytesize = (int)ss.st_size;
+   dl_argv[i++] = (char*)"-U";
+   dl_argv[i++] = (char*) user_agent;
    dl_argv[i++] = (char*)"-c";
    dl_argv[i++] = (char*)"--load-cookies";
    dl_argv[i++] = dStrconcat(dGethomedir(), "/.dillo/cookies.txt", NULL);
@@ -520,7 +525,8 @@ void DLItem::log_text_add(const char *buf, ssize_t st)
          if (isdigit(*q++ = *p)) {
             // keep here
          } else if (*p == 'K') {
-            for (--q; isdigit(q[-1]); --q) ; log_state = ST_discard;
+            for (--q; isdigit(q[-1]); --q) ; 
+            log_state = ST_discard;
          } else {
             log_state = ST_copy;
          }
