@@ -464,8 +464,9 @@ static bool_t Tls_check_cert_strength(SSL *ssl, Server_t *srv, int *choice)
           * then trim off the "With..." part.
           */
          b = BIO_new(BIO_s_mem());
-         const X509_ALGOR *sigalg = X509_get0_tbs_sigalg(cert);
-         rc = i2a_ASN1_OBJECT(b, sigalg->algorithm);
+         const ASN1_OBJECT *algorithm;
+         X509_ALGOR_get0(&algorithm, NULL, NULL, X509_get0_tbs_sigalg(cert));
+         rc = i2a_ASN1_OBJECT(b, algorithm);
 
          if (rc > 0) {
             rc = BIO_gets(b, buf, buflen);
@@ -1271,11 +1272,20 @@ void a_Tls_openssl_connect(int fd, const DilloUrl *url)
  */
 static int Tls_handle_error(Conn_t *conn, int ret, const char *where)
 {
+   /* Success */
+   if (ret > 0) {
+      errno = 0;
+      return ret;
+   }
+
    SSL *ssl = conn->ssl;
    int err1_ret = SSL_get_error(ssl, ret);
    if (err1_ret == SSL_ERROR_NONE) {
       errno = 0;
       return ret;
+   } else if (err1_ret == SSL_ERROR_ZERO_RETURN) {
+      errno = 0;
+      return 0;
    } else if (err1_ret == SSL_ERROR_WANT_READ || err1_ret == SSL_ERROR_WANT_WRITE) {
       errno = EAGAIN;
       return -1;
