@@ -17,6 +17,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/** @file
+ * Dillo web browser.
+ */
+
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -45,20 +49,23 @@
 
 #include "dns.h"
 #include "web.hh"
+#include "IO/tls.h"
 #include "IO/Url.h"
 #include "IO/mime.h"
 #include "capi.h"
 #include "dicache.h"
 #include "cookies.h"
+#include "hsts.h"
 #include "domain.h"
 #include "auth.h"
 #include "styleengine.hh"
 
-#include "lout/debug.hh"
 #include "dw/fltkcore.hh"
+#include "dw/widget.hh"
 #include "dw/textblock.hh"
+#include "dw/table.hh"
 
-/*
+/**
  * Command line options structure
  */
 typedef enum {
@@ -105,7 +112,7 @@ static const CLI_options Options[] = {
  * SIGCHLD handling ----------------------------------------------------------
  */
 
-/*
+/**
  * Avoid our children (Dpid) to become zombies. :-)
  * Notes:
  *   . We let sigaction block SIGCHLD while in the handler.
@@ -137,7 +144,7 @@ static void raw_sigchld2(int signum)
    ++signum; /* compiler happiness */
 }
 
-/*
+/**
  * Establish SIGCHLD handler
  */
 static void est_sigchld(void)
@@ -157,7 +164,7 @@ static void est_sigchld(void)
 
 //----------------------------------------------------------------------------
 
-/*
+/**
  * Print help text generated from the options structure
  */
 static void printHelp(const char *cmdname, const CLI_options *options)
@@ -173,7 +180,7 @@ static void printHelp(const char *cmdname, const CLI_options *options)
           "\n");
 }
 
-/*
+/**
  * Return the maximum number of option arguments
  */
 static int numOptions(const CLI_options *options)
@@ -186,7 +193,7 @@ static int numOptions(const CLI_options *options)
    return max;
 }
 
-/*
+/**
  * Get next command line option.
  */
 static OptID getCmdOption(const CLI_options *options, int argc, char **argv,
@@ -237,7 +244,7 @@ static OptID getCmdOption(const CLI_options *options, int argc, char **argv,
    return opt_id;
 }
 
-/*
+/**
  * Set FL_NORMAL_LABEL to interpret neither symbols (@) nor shortcuts (&),
  * and FL_FREE_LABELTYPE to interpret shortcuts.
  */
@@ -281,7 +288,7 @@ static void custMenuLabelMeasure(const Fl_Label* o, int& W, int& H)
    fl_measure(o->value, W, H, interpret_symbols);
 }
 
-/*
+/**
  * Tell the user if default/pref fonts can't be found.
  */
 static void checkFont(const char *name, const char *type)
@@ -299,7 +306,7 @@ static void checkPreferredFonts()
    checkFont(prefs.font_fantasy, "fantasy");
 }
 
-/*
+/**
  * Set UI color. 'color' is an 0xrrggbb value, whereas 'default_val' is a fltk
  * color (index 0-0xFF, or 0xrrggbb00).
  */
@@ -342,7 +349,7 @@ static void setColors()
                   Fl::get_color(FL_FOREGROUND_COLOR));
 }
 
-/*
+/**
  * Given a command line argument, build a DilloUrl for it.
  */
 static DilloUrl *makeStartUrl(char *str, bool local)
@@ -377,11 +384,6 @@ static DilloUrl *makeStartUrl(char *str, bool local)
  */
 int main(int argc, char **argv)
 {
-   DBG_OBJ_COLOR("#c0ff80", "dw::*");
-   DBG_OBJ_COLOR("#c0c0ff", "dw::fltk::*");
-   DBG_OBJ_COLOR("#ffa0a0", "dw::core::*");
-   DBG_OBJ_COLOR("#ffe0a0", "dw::core::style::*");
-
    uint_t opt_id;
    uint_t options_got = 0;
    uint32_t xid = 0;
@@ -466,15 +468,19 @@ int main(int argc, char **argv)
    a_Dns_init();
    a_Web_init();
    a_Http_init();
+   a_Tls_init();
    a_Mime_init();
    a_Capi_init();
    a_Dicache_init();
    a_Bw_init();
    a_Cookies_init();
+   a_Hsts_init(Paths::getPrefsFP(PATHS_HSTS_PRELOAD));
    a_Auth_init();
    a_UIcmd_init();
    StyleEngine::init();
 
+   dw::core::Widget::setAdjustMinWidth (prefs.adjust_min_width);
+   dw::Table::setAdjustTableMinWidth (prefs.adjust_table_min_width);
    dw::Textblock::setPenaltyHyphen (prefs.penalty_hyphen);
    dw::Textblock::setPenaltyHyphen2 (prefs.penalty_hyphen_2);
    dw::Textblock::setPenaltyEmDashLeft (prefs.penalty_em_dash_left);
@@ -582,9 +588,11 @@ int main(int argc, char **argv)
     */
    a_Domain_freeall();
    a_Cookies_freeall();
+   a_Hsts_freeall();
    a_Cache_freeall();
    a_Dicache_freeall();
    a_Http_freeall();
+   a_Tls_freeall();
    a_Dns_freeall();
    a_History_freeall();
    a_Prefs_freeall();
