@@ -2,6 +2,7 @@
  * Preferences parser
  *
  * Copyright (C) 2006-2009 Jorge Arellano Cid <jcid@dillo.org>
+ * Copyright (C) 2024 Rodrigo Arias Mallo <rodarima@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -9,6 +10,11 @@
  * (at your option) any later version.
  */
 
+/**
+ * @file
+ * Preferences parser
+ */
+
 #include <sys/types.h>
 #include <stdlib.h>
 #include <locale.h>            /* for setlocale */
@@ -42,7 +48,7 @@ typedef struct {
    int count;
 } SymNode_t;
 
-/*
+/**
  * Parse a name/value pair and set preferences accordingly.
  */
 static int parseOption(char *name, char *value,
@@ -136,16 +142,16 @@ static int parseOption(char *name, char *value,
    return 0;
 }
 
-/*
+/**
  * Parses the dillorc and sets the values in the prefs structure.
  */
 void PrefsParser::parse(FILE *fp)
 {
    char *line, *name, *value, *oldLocale;
-   int st;
+   int st, line_number = 1;
 
    /* Symbol array, sorted alphabetically */
-   SymNode_t symbols[] = {
+   static SymNode_t symbols[] = {
       { "allow_white_bg", &prefs.allow_white_bg, PREFS_BOOL, 0 },
       { "white_bg_replacement", &prefs.white_bg_replacement, PREFS_COLOR, 0 },
       { "bg_color", &prefs.bg_color, PREFS_COLOR, 0 },
@@ -167,11 +173,17 @@ void PrefsParser::parse(FILE *fp)
       { "home", &prefs.home, PREFS_URL, 0 },
       { "http_language", &prefs.http_language, PREFS_STRING, 0 },
       { "http_max_conns", &prefs.http_max_conns, PREFS_INT32, 0 },
+      { "http_persistent_conns", &prefs.http_persistent_conns, PREFS_BOOL, 0 },
       { "http_proxy", &prefs.http_proxy, PREFS_URL, 0 },
       { "http_proxyuser", &prefs.http_proxyuser, PREFS_STRING, 0 },
       { "http_referer", &prefs.http_referer, PREFS_STRING, 0 },
+      { "http_strict_transport_security",&prefs.http_strict_transport_security,
+        PREFS_BOOL, 0 },
+      { "http_force_https", &prefs.http_force_https, PREFS_BOOL, 0 },
       { "http_user_agent", &prefs.http_user_agent, PREFS_STRING, 0 },
       { "limit_text_width", &prefs.limit_text_width, PREFS_BOOL, 0 },
+      { "adjust_min_width", &prefs.adjust_min_width, PREFS_BOOL, 0 },
+      { "adjust_table_min_width", &prefs.adjust_table_min_width, PREFS_BOOL, 0 },
       { "load_images", &prefs.load_images, PREFS_BOOL, 0 },
       { "load_background_images", &prefs.load_background_images, PREFS_BOOL, 0 },
       { "load_stylesheets", &prefs.load_stylesheets, PREFS_BOOL, 0 },
@@ -180,10 +192,13 @@ void PrefsParser::parse(FILE *fp)
       { "middle_click_opens_new_tab", &prefs.middle_click_opens_new_tab,
         PREFS_BOOL, 0 },
       { "right_click_closes_tab", &prefs.right_click_closes_tab, PREFS_BOOL, 0 },
+      { "scroll_switches_tabs", &prefs.scroll_switches_tabs, PREFS_BOOL, 0 },
+      { "scroll_switches_tabs_reverse", &prefs.scroll_switches_tabs_reverse, PREFS_BOOL, 0 },
       { "no_proxy", &prefs.no_proxy, PREFS_STRING, 0 },
       { "panel_size", &prefs.panel_size, PREFS_PANEL_SIZE, 0 },
       { "parse_embedded_css", &prefs.parse_embedded_css, PREFS_BOOL, 0 },
       { "save_dir", &prefs.save_dir, PREFS_STRING, 0 },
+      { "scroll_step", &prefs.scroll_step, PREFS_INT32, 0 },
       { "search_url", &prefs.search_urls, PREFS_STRINGS, 0 },
       { "show_back", &prefs.show_back, PREFS_BOOL, 0 },
       { "show_bookmarks", &prefs.show_bookmarks, PREFS_BOOL, 0 },
@@ -216,8 +231,8 @@ void PrefsParser::parse(FILE *fp)
       { "ui_tab_bg_color", &prefs.ui_tab_bg_color, PREFS_COLOR, 0 },
       { "ui_tab_active_fg_color", &prefs.ui_tab_active_fg_color, PREFS_COLOR, 0 },
       { "ui_tab_fg_color", &prefs.ui_tab_fg_color, PREFS_COLOR, 0 },
+      { "ui_tab_height", &prefs.ui_tab_height, PREFS_INT32, 0 },
       { "ui_text_bg_color", &prefs.ui_text_bg_color, PREFS_COLOR, 0 },
-      { "w3c_plus_heuristics", &prefs.w3c_plus_heuristics, PREFS_BOOL, 0 },
       { "penalty_hyphen", &prefs.penalty_hyphen, PREFS_FRACTION_100, 0 },
       { "penalty_hyphen_2", &prefs.penalty_hyphen_2, PREFS_FRACTION_100, 0 },
       { "penalty_em_dash_left", &prefs.penalty_em_dash_left,
@@ -242,11 +257,11 @@ void PrefsParser::parse(FILE *fp)
          _MSG("prefsparser: name=%s, value=%s\n", name, value);
          parseOption(name, value, symbols, sizeof(symbols) / sizeof(symbols[0]));
       } else if (st < 0) {
-         MSG_ERR("prefsparser: Syntax error in dillorc:"
-                 " name=\"%s\" value=\"%s\"\n", name, value);
+         MSG_ERR("prefsparser: Syntax error in dillorc line %d:"
+                 " name=\"%s\" value=\"%s\"\n", line_number, name, value);
       }
-
       dFree(line);
+      line_number++;
    }
    fclose(fp);
 
